#[repr(C)]
pub struct randombytes_implementation {
pub implementation_name: Option<unsafe extern "C" fn() -> *const c_char>,
pub random: Option<unsafe extern "C" fn() -> u32>,
pub stir: Option<unsafe extern "C" fn()>,
pub uniform: Option<unsafe extern "C" fn(upper_bound: u32) -> u32>,
pub buf: Option<unsafe extern "C" fn(buf: *mut c_void, size: usize)>,
pub close: Option<unsafe extern "C" fn() -> c_int>,
}
random: Option<unsafe extern "C" fn() -> u32>
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.